@@ -126,6 +126,10 @@ void LaTeX::deleteFilesOnError() const
 	FileName const bbl(changeExtension(file.absFilename(), ".bbl"));
 	bbl.removeFile();
 
+	// biber file
+	FileName const bcf(changeExtension(file.absFilename(), ".bcf"));
+	bcf.removeFile();
+
 	// makeindex file
 	FileName const ind(changeExtension(file.absFilename(), ".ind"));
 	ind.removeFile();
@@ -273,6 +277,12 @@ int LaTeX::run(TeXErrors & terr)
 	if (head.haschanged(glofile))
 		rerun |= runMakeIndexNomencl(file, ".glo", ".gls");
 
+	// check if we're using biber instead of bibtex
+	// biber writes no info to the aux file, so we just check
+	// if a bcf file exists (and if it was updated)
+	FileName const bcffile(changeExtension(file.absFilename(), ".bcf"));
+	bool const biber = head.exist(bcffile);
+
 	// run bibtex
 	// if (scanres & UNDEF_CIT || scanres & RERUN || run_bibtex)
 	if (scanres & UNDEF_CIT || run_bibtex) {
@@ -282,13 +292,21 @@ int LaTeX::run(TeXErrors & terr)
 		// no checks for now
 		LYXERR(Debug::LATEX, "Running BibTeX.");
 		message(_("Running BibTeX."));
-		updateBibtexDependencies(head, bibtex_info);
-		rerun |= runBibTeX(bibtex_info, runparams);
+		updateBibtexDependencies(head, bibtex_info, biber);
+		rerun |= runBibTeX(bibtex_info, runparams, biber);
+		if (biber) {
+			// since biber writes no info to the aux file, we have
+			// to parse the blg file (which only exists after biber
+			// was first issued)
+			FileName const blgfile(changeExtension(file.absFilename(), ".blg"));
+			if (blgfile.exists())
+				scanBlgFile(head);
+		}
 	} else if (!had_depfile) {
 		/// If we run pdflatex on the file after running latex on it,
 		/// then we do not need to run bibtex, but we do need to
 		/// insert the .bib and .bst files into the .dep-pdf file.
-		updateBibtexDependencies(head, bibtex_info);
+		updateBibtexDependencies(head, bibtex_info, biber);
 	}
 
 	// 2
@@ -334,8 +352,8 @@ int LaTeX::run(TeXErrors & terr)
 		// no checks for now
 		LYXERR(Debug::LATEX, "Running BibTeX.");
 		message(_("Running BibTeX."));
-		updateBibtexDependencies(head, bibtex_info);
-		rerun |= runBibTeX(bibtex_info, runparams);
+		updateBibtexDependencies(head, bibtex_info, biber);
+		rerun |= runBibTeX(bibtex_info, runparams, biber);
 	}
 
 	// 4
@@ -524,7 +542,8 @@ void LaTeX::scanAuxFile(FileName const & file, Aux_Info & aux_info)
 
 
 void LaTeX::updateBibtexDependencies(DepTable & dep,
-				     vector<Aux_Info> const & bibtex_info)
+				     vector<Aux_Info> const & bibtex_info,
+				     bool biber)
 {
 	// Since a run of Bibtex mandates more latex runs it is ok to
 	// remove all ".bib" and ".bst" files.
@@ -548,16 +567,22 @@ void LaTeX::updateBibtexDependencies(DepTable & dep,
 				dep.insert(file, true);
 		}
 	}
+
+	// biber writes nothing into the aux file.
+	// Instead, we have to scan the blg file
+	if (biber) {
+		scanBlgFile(dep);
+	}
 }
 
 
 bool LaTeX::runBibTeX(vector<Aux_Info> const & bibtex_info,
-		      OutputParams const & runparams)
+		      OutputParams const & runparams, bool biber)
 {
 	bool result = false;
 	for (vector<Aux_Info>::const_iterator it = bibtex_info.begin();
 	     it != bibtex_info.end(); ++it) {
-		if (it->databases.empty())
+		if (!biber && it->databases.empty())
 			continue;
 		result = true;
 
@@ -733,6 +758,12 @@ int LaTeX::scanLogFile(TeXErrors & terr)
 					++num_errors;
 				}
 			}
+
+			if (prefixIs(token, "! Paragraph ended before \\Hy@setref@link was complete.")){
+					// bug 7344. We must rerun LaTeX if hyperref has been toggled.
+					retval |= ERROR_RERUN;
+					LYXERR(Debug::LATEX, "Force rerun.");
+			}
 		} else {
 			// information messages, TeX warnings and other
 			// warnings we have not caught earlier.
@@ -1077,4 +1108,30 @@ void LaTeX::deplog(DepTable & head)
 }
 
 
+void LaTeX::scanBlgFile(DepTable & dep)
+{
+	FileName const blg_file(changeExtension(file.absFilename(), "blg"));
+	LYXERR(Debug::LATEX, "Scanning blg file: " << blg_file);
+
+	ifstream ifs(blg_file.toFilesystemEncoding().c_str());
+	string token;
+	static regex const reg1(".*Found bibtex data file '([^']+).*");
+
+	while (getline(ifs, token)) {
+		token = rtrim(token, "\r");
+		smatch sub;
+		// FIXME UNICODE: We assume that citation keys and filenames
+		// in the aux file are in the file system encoding.
+		token = to_utf8(from_filesystem8bit(token));
+		if (regex_match(token, sub, reg1)) {
+			string data = sub.str(1);
+			if (!data.empty()) {
+				LYXERR(Debug::LATEX, "Found bib file: " << data);
+				handleFoundFile(data, dep);
+			}
+		}
+	} 
+}
+
+
 } // namespace lyx
