@@ -645,7 +645,7 @@ GuiDocument::GuiDocument(GuiView & lv)
 	connect(pageLayoutModule->papersizeCO, SIGNAL(activated(int)),
 		this, SLOT(papersizeChanged(int)));
 	connect(pageLayoutModule->portraitRB, SIGNAL(clicked()),
-		this, SLOT(portraitChanged()));
+		this, SLOT(change_adaptor()));
 	connect(pageLayoutModule->papersizeCO, SIGNAL(activated(int)),
 		this, SLOT(change_adaptor()));
 	connect(pageLayoutModule->paperheightLE, SIGNAL(textChanged(const QString &)),
@@ -1088,12 +1088,8 @@ void GuiDocument::enableSkip(bool skip)
 		setSkip(textLayoutModule->skipCO->currentIndex());
 }
 
-void GuiDocument::portraitChanged()
-{
-	setMargins(pageLayoutModule->papersizeCO->currentIndex());
-}
 
-void GuiDocument::setMargins(bool custom)
+void GuiDocument::setMargins()
 {
 	bool const extern_geometry =
 		documentClass().provides("geometry");
@@ -1101,10 +1097,10 @@ void GuiDocument::setMargins(bool custom)
 	if (extern_geometry) {
 		marginsModule->marginCB->setChecked(false);
 		setCustomMargins(true);
-		return;
+	} else {
+		marginsModule->marginCB->setChecked(!bp_.use_geometry);
+		setCustomMargins(!bp_.use_geometry);
 	}
-	marginsModule->marginCB->setChecked(custom);
-	setCustomMargins(custom);
 }
 
 
@@ -1369,6 +1365,9 @@ void GuiDocument::classChanged()
 
 
 namespace {
+	// FIXME unicode 
+	// both of these should take a vector<docstring>
+	
 	// This is an insanely complicated attempt to make this sort of thing
 	// work with RTL languages.
 	docstring formatStrVec(vector<string> const & v, docstring const & s) 
@@ -1377,22 +1376,24 @@ namespace {
 		if (v.size() == 0)
 			return docstring();
 		if (v.size() == 1) 
-			return from_utf8(v[0]);
+			return translateIfPossible(from_utf8(v[0]));
 		if (v.size() == 2) {
 			docstring retval = _("%1$s and %2$s");
 			retval = subst(retval, _("and"), s);
-			return bformat(retval, from_utf8(v[0]), from_utf8(v[1]));
+			return bformat(retval, translateIfPossible(from_utf8(v[0])),
+				       translateIfPossible(from_utf8(v[1])));
 		}
 		// The idea here is to format all but the last two items...
 		int const vSize = v.size();
 		docstring t2 = _("%1$s, %2$s");
-		docstring retval = from_utf8(v[0]);
+		docstring retval = translateIfPossible(from_utf8(v[0]));
 		for (int i = 1; i < vSize - 2; ++i)
-			retval = bformat(t2, retval, from_utf8(v[i])); 
+			retval = bformat(t2, retval, translateIfPossible(from_utf8(v[i]))); 
 		//...and then to  plug them, and the last two, into this schema
 		docstring t = _("%1$s, %2$s, and %3$s");
 		t = subst(t, _("and"), s);
-		return bformat(t, retval, from_utf8(v[vSize - 2]), from_utf8(v[vSize - 1]));
+		return bformat(t, retval, translateIfPossible(from_utf8(v[vSize - 2])),
+			       translateIfPossible(from_utf8(v[vSize - 1])));
 	}
 	
 	vector<string> idsToNames(vector<string> const & idList)
@@ -1403,7 +1404,8 @@ namespace {
 		for (; it != end; ++it) {
 			LyXModule const * const mod = moduleList[*it];
 			if (!mod)
-				retval.push_back(*it + " (Unavailable)");
+				retval.push_back(to_utf8(bformat(_("%1$s (unavailable)"), 
+						translateIfPossible(from_utf8(*it)))));
 			else
 				retval.push_back(mod->getName());
 		}
@@ -1683,10 +1685,14 @@ void GuiDocument::applyView()
 	case 2:
 		bp_.spacing().set(Spacing::Double);
 		break;
-	case 3:
-		bp_.spacing().set(Spacing::Other,
-			fromqstr(textLayoutModule->lspacingLE->text()));
+	case 3: {
+		string s = fromqstr(textLayoutModule->lspacingLE->text());
+		if (s.empty())
+			bp_.spacing().set(Spacing::Single);
+		else
+			bp_.spacing().set(Spacing::Other, s);
 		break;
+		}
 	}
 
 	if (textLayoutModule->twoColumnCB->isChecked())
@@ -1777,10 +1783,6 @@ void GuiDocument::applyView()
 	bp_.papersize = PAPER_SIZE(
 		pageLayoutModule->papersizeCO->currentIndex());
 
-	// custom, A3, B3 and B4 paper sizes need geometry
-	int psize = pageLayoutModule->papersizeCO->currentIndex();
-	bool geom_papersize = (psize == 1 || psize == 5 || psize == 8 || psize == 9);
-
 	bp_.paperwidth = widgetsToLength(pageLayoutModule->paperwidthLE,
 		pageLayoutModule->paperwidthUnitCO);
 
@@ -1798,8 +1800,7 @@ void GuiDocument::applyView()
 		bp_.orientation = ORIENTATION_PORTRAIT;
 
 	// margins
-	bp_.use_geometry = !marginsModule->marginCB->isChecked()
-		|| geom_papersize;
+	bp_.use_geometry = !marginsModule->marginCB->isChecked();
 
 	Ui::MarginsUi const * m = marginsModule;
 
@@ -1812,6 +1813,7 @@ void GuiDocument::applyView()
 	bp_.footskip = widgetsToLength(m->footskipLE, m->footskipUnit);
 	bp_.columnsep = widgetsToLength(m->columnsepLE, m->columnsepUnit);
 
+	// branches
 	branchesModule->apply(bp_);
 
 	// PDF support
@@ -2119,17 +2121,15 @@ void GuiDocument::paramsToDialog()
 	pageLayoutModule->facingPagesCB->setChecked(
 		bp_.sides == TwoSides);
 
-
 	lengthToWidgets(pageLayoutModule->paperwidthLE,
 		pageLayoutModule->paperwidthUnitCO, bp_.paperwidth, defaultUnit);
-
 	lengthToWidgets(pageLayoutModule->paperheightLE,
 		pageLayoutModule->paperheightUnitCO, bp_.paperheight, defaultUnit);
 
 	// margins
 	Ui::MarginsUi * m = marginsModule;
 
-	setMargins(!bp_.use_geometry);
+	setMargins();
 
 	lengthToWidgets(m->topLE, m->topUnit,
 		bp_.topmargin, defaultUnit);
