@@ -234,8 +234,7 @@ GuiWorkArea::GuiWorkArea(Buffer & buffer, GuiView & lv)
 	: buffer_view_(new BufferView(buffer)), lyx_view_(&lv),
 	cursor_visible_(false),
 	need_resize_(false), schedule_redraw_(false),
-	preedit_lines_(1), completer_(new GuiCompleter(this, this)),
-	context_target_pos_()
+	preedit_lines_(1), completer_(new GuiCompleter(this, this))
 {
 	buffer.workAreaManager().add(this);
 	// Setup the signals
@@ -628,31 +627,37 @@ bool GuiWorkArea::event(QEvent * e)
 
 void GuiWorkArea::contextMenuEvent(QContextMenuEvent * e)
 {
-	QPoint pos;
-	if (e->reason() == QContextMenuEvent::Mouse)
-		// the position is set on mouse press
-		pos = context_target_pos_;
-	else
-		pos = e->pos();
-	Cursor const & cur = buffer_view_->cursor();
-	if (e->reason() == QContextMenuEvent::Keyboard && cur.inTexted()) {
-		// Do not access the context menu of math right in front of before
-		// the cursor. This does not work when the cursor is in text.
-		Inset * inset = cur.paragraph().getInset(cur.pos());
-		if (inset && inset->asInsetMath())
-			--pos.rx();
-		else if (cur.pos() > 0) {
-			Inset * inset = cur.paragraph().getInset(cur.pos() - 1);
-			if (inset)
-				++pos.rx();
+	docstring name;
+	if (e->reason() == QContextMenuEvent::Mouse) {
+		// the context menu name is set on mouse press
+		name = context_menu_name_;
+	} else {
+		QPoint pos = e->pos();
+		Cursor const & cur = buffer_view_->cursor();
+		if (e->reason() == QContextMenuEvent::Keyboard && cur.inTexted()) {
+			// Do not access the context menu of math right in front of before
+			// the cursor. This does not work when the cursor is in text.
+			Inset * inset = cur.paragraph().getInset(cur.pos());
+			if (inset && inset->asInsetMath())
+				--pos.rx();
+			else if (cur.pos() > 0) {
+				Inset * inset = cur.paragraph().getInset(cur.pos() - 1);
+				if (inset)
+					++pos.rx();
+			}	
 		}
+		name = buffer_view_->contextMenu(pos.x(), pos.y());
 	}
-	docstring name = buffer_view_->contextMenu(pos.x(), pos.y());
+
 	if (name.empty()) {
 		QAbstractScrollArea::contextMenuEvent(e);
 		return;
 	}
-	QMenu * menu = guiApp->menus().menu(toqstr(name), *lyx_view_);
+
+	// always show mnemonics when the keyboard is used to show the context menu
+	// FIXME: This should be fixed in Qt itself
+	bool const keyboard = (e->reason() == QContextMenuEvent::Keyboard);
+	QMenu * menu = guiApp->menus().menu(toqstr(name), *lyx_view_, keyboard);
 	if (!menu) {
 		QAbstractScrollArea::contextMenuEvent(e);
 		return;
@@ -692,8 +697,12 @@ void GuiWorkArea::mousePressEvent(QMouseEvent * e)
 		return;
 	}
 
+	// Save the context menu on mouse press, because also the mouse
+	// cursor is set on mouse press. Afterwards, we can either release
+	// the mousebutton somewhere else, or the cursor might have moved
+	// due to the DEPM.
 	if (e->button() == Qt::RightButton)
-		context_target_pos_ = e->pos();
+		context_menu_name_ = buffer_view_->contextMenu(e->x(), e->y());
 
 	inputContext()->reset();
 
