@@ -65,6 +65,9 @@
 #include <QHash>
 #include <QList>
 #include <QMenuBar>
+#if QT_VERSION >= 0x040600
+#include <QProxyStyle>
+#endif
 #include <QString>
 
 #include <boost/shared_ptr.hpp>
@@ -1223,13 +1226,35 @@ void Menu::Impl::populate(QMenu & qMenu, MenuDefinition const & menu)
 	}
 }
 
+
+#if defined(Q_WS_WIN) && (QT_VERSION >= 0x040600)
+class AlwaysMnemonicStyle : public QProxyStyle {
+public:
+	int styleHint(StyleHint hint, const QStyleOption *opt = 0, const QWidget *widget = 0,
+		QStyleHintReturn *returnData = 0) const 
+	{
+		if (hint == QStyle::SH_UnderlineShortcut)
+			return 1;
+		return QProxyStyle::styleHint(hint, opt, widget, returnData);
+	}
+};
+#endif
+
 /////////////////////////////////////////////////////////////////////
 // Menu implementation
 /////////////////////////////////////////////////////////////////////
 
-Menu::Menu(GuiView * gv, QString const & name, bool top_level)
+Menu::Menu(GuiView * gv, QString const & name, bool top_level,
+	bool keyboard)
 : QMenu(gv), d(new Menu::Impl)
 {
+#if defined(Q_WS_WIN) && (QT_VERSION >= 0x040600)
+	if (keyboard)
+		setStyle(new AlwaysMnemonicStyle);
+#else
+		(void) keyboard;
+#endif
+
 	d->top_level_menu = top_level? new MenuDefinition : 0;
 	d->view = gv;
 	d->name = name;
@@ -1680,7 +1705,7 @@ void Menus::updateMenu(Menu * qmenu)
 }
 
 
-Menu * Menus::menu(QString const & name, GuiView & view)
+Menu * Menus::menu(QString const & name, GuiView & view, bool keyboard)
 {
 	LYXERR(Debug::GUI, "Context menu requested: " << name);
 	Menu * menu = d->name_map_[&view].value(name, 0);
@@ -1689,7 +1714,7 @@ Menu * Menus::menu(QString const & name, GuiView & view)
 		return 0;
 	}
 
-	menu = new Menu(&view, name, true);
+	menu = new Menu(&view, name, true, keyboard);
 	d->name_map_[&view][name] = menu;
 	return menu;
 }
